==> nextcloud-16.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/zh_CN.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您想要添加来自 {owner}@{remote} 的远程共享 {name} 吗？",
    "Remote share" : "远程共享",
    "Remote share password" : "远程共享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程共享",
    "Copy" : "复制",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "Invalid Federated Cloud ID" : "联合云 ID 不正确",
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器共享功能",
    "Couldn't establish a federated share." : "无法建立一个远程共享",
    "Couldn't establish a federated share, maybe the password was wrong." : "无法建立共享，可能密码是错误的。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "共享协作请求发送成功！您将收到邀请。注意留意您的通知提醒。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "无法建立联合共享，可能是要联合的服务器版本太旧（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允许从此服务器发送联合分组共享。",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "共享 %1$s 失败，因为该项已经共享给 %2$s",
    "Not allowed to create a federated share with the same user" : "不能给您自己共享文件",
    "File is already shared with %s" : "文件已经共享与 %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "共享 %1$s 失败，无法找到 %2$s，可能该服务器当前无法访问或者使用了自签名证书。",
    "Could not find share" : "没有发现共享",
    "Federated sharing" : "联合云共享",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "您收到“%3$s\"做为远程共享从”%1$s（代表\"%2$s）",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您得到 {share} 是从 {user} 做为远程共享（代替 {behalf} ）",
    "You received \"%3$s\" as a remote share from %1$s" : "您从“%1$s\"得到\"%3$s\"做为远程共享",
    "You received {share} as a remote share from {user}" : "您从 {user} 收到了 {share} 作为远程共享",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "通过我的联合云 ID，共享给我，看%s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "通过我的 #Nextcloud 联合云 ID 与我共享",
    "Sharing" : "共享",
    "Federated file sharing" : "联合文件共享",
    "Provide federated file sharing across servers" : "在服务器间提供联合文件共享",
    "Federated Cloud Sharing" : "联合云共享",
    "Open documentation" : "打开文档",
    "Adjust how people can share between servers." : "调整人们如何在服务器之间共享。",
    "Allow users on this server to send shares to other servers" : "允许用户共享文件给其他服务器上的用户",
    "Allow users on this server to receive shares from other servers" : "允许用户从其他服务器接收共享",
    "Allow users on this server to send shares to groups on other servers" : "允许此服务器上的用户向其他服务器上的分组发送共享",
    "Allow users on this server to receive group shares from other servers" : "允许此服务器上的用户接收其他服务器的分组共享",
    "Search global and public address book for users" : "在全局和公开地址簿中寻找用户",
    "Allow users to publish their data to a global and public address book" : "允许用户将其数据发布到全球和公共通讯录",
    "Federated Cloud" : "联合云",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以和使用了Nextcloud服务器或其他兼容Open Cloud Mesh（OCM）的服务器和服务的任何人共享！只需将他们的联合云 ID 放在共享对话框中。联合云 ID 看起来像 person@cloud.example.com",
    "Your Federated Cloud ID:" : "您的联合云 ID：",
    "Share it so your friends can share files with you:" : "使用共享，以便您的朋友可以与您共享文件：",
    "Add to your website" : "添加到您的网站",
    "Share with me via Nextcloud" : "通过联合云与我共享",
    "HTML Code:" : "HTML 代码："
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.4.tgz: nextcloud/apps/federatedfilesharing/l10n/zh_CN.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您想要添加来自 {owner}@{remote} 的远程共享 {name} 吗？",
    "Remote share" : "远程共享",
    "Remote share password" : "远程共享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程共享",
    "Copy" : "复制",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "Invalid Federated Cloud ID" : "联合云 ID 不正确",
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器共享功能",
    "Couldn't establish a federated share." : "无法建立一个远程共享",
    "Couldn't establish a federated share, maybe the password was wrong." : "无法建立共享，可能密码是错误的。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "共享协作请求发送成功！您将收到邀请。注意留意您的通知提醒。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "无法建立联合共享，可能是要联合的服务器版本太旧（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允许从此服务器发送联合分组共享。",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "共享 %1$s 失败，因为该项已经共享给 %2$s",
    "Not allowed to create a federated share with the same user" : "不能给您自己共享文件",
    "File is already shared with %s" : "文件已经共享与 %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "共享 %1$s 失败，无法找到 %2$s，可能该服务器当前无法访问或者使用了自签名证书。",
    "Could not find share" : "没有发现共享",
    "Federated sharing" : "联合云共享",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "您收到了来自%4$s（%1$s）的作为远程共享的\"%3$s\"（代表%5$s（%2$s））",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您得到 {share} 是从 {user} 做为远程共享（代替 {behalf} ）",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "您收到了来自%4$s（%1$s）的作为远程共享的\"%3$s\"",
    "You received {share} as a remote share from {user}" : "您从 {user} 收到了 {share} 作为远程共享",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "通过我的联合云 ID，共享给我，看%s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "通过我的 #Nextcloud 联合云 ID 与我共享",
    "Sharing" : "共享",
    "Federated file sharing" : "联合文件共享",
    "Provide federated file sharing across servers" : "在服务器间提供联合文件共享",
    "Federated Cloud Sharing" : "联合云共享",
    "Open documentation" : "打开文档",
    "Adjust how people can share between servers." : "调整人们如何在服务器之间共享。",
    "Allow users on this server to receive shares from other servers" : "允许用户从其他服务器接收共享",
    "Allow users on this server to send shares to groups on other servers" : "允许此服务器上的用户向其他服务器上的分组发送共享",
    "Allow users on this server to receive group shares from other servers" : "允许此服务器上的用户接收其他服务器的分组共享",
    "Search global and public address book for users" : "在全局和公开地址簿中寻找用户",
    "Allow users to publish their data to a global and public address book" : "允许用户将其数据发布到全球和公共通讯录",
    "Federated Cloud" : "联合云",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以和使用了 Nextcloud 服务器或其他兼容 Open Cloud Mesh（OCM）的服务器和服务的任何人共享！只需将他们的联合云 ID 放在共享对话框中。联合云 ID 看起来像 person@cloud.example.com",
    "Your Federated Cloud ID:" : "您的联合云 ID：",
    "Share it so your friends can share files with you:" : "使用共享，以便您的朋友可以与您共享文件：",
    "Add to your website" : "添加到您的网站",
    "Share with me via Nextcloud" : "通过联合云与我共享",
    "HTML Code:" : "HTML 代码：",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "您收到“%3$s\"做为远程共享从”%1$s（代表\"%2$s）",
    "You received \"%3$s\" as a remote share from %1$s" : "您从“%1$s\"得到\"%3$s\"做为远程共享",
    "Allow users on this server to send shares to other servers" : "允许用户共享文件给其他服务器上的用户"
},
"nplurals=1; plural=0;");
